@@ -36,7 +36,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateApplication", params)
+            headers = request.headers
+            body = self.call("CreateApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateApplicationResponse()
@@ -64,7 +65,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCosToken", params)
+            headers = request.headers
+            body = self.call("CreateCosToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCosTokenResponse()
@@ -92,7 +94,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEnvironment", params)
+            headers = request.headers
+            body = self.call("CreateEnvironment", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEnvironmentResponse()
@@ -120,7 +123,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateResource", params)
+            headers = request.headers
+            body = self.call("CreateResource", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateResourceResponse()
@@ -151,7 +155,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteApplication", params)
+            headers = request.headers
+            body = self.call("DeleteApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteApplicationResponse()
@@ -179,7 +184,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteIngress", params)
+            headers = request.headers
+            body = self.call("DeleteIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteIngressResponse()
@@ -207,7 +213,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeployApplication", params)
+            headers = request.headers
+            body = self.call("DeployApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeployApplicationResponse()
@@ -235,7 +242,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeApplicationPods", params)
+            headers = request.headers
+            body = self.call("DescribeApplicationPods", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeApplicationPodsResponse()
@@ -253,6 +261,35 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeApplicationsStatus(self, request):
+        """单环境下所有应用状态查看
+
+        :param request: Request instance for DescribeApplicationsStatus.
+        :type request: :class:`tencentcloud.tem.v20210701.models.DescribeApplicationsStatusRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.DescribeApplicationsStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeApplicationsStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeApplicationsStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDeployApplicationDetail(self, request):
         """获取分批发布详情
 
@@ -263,7 +300,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDeployApplicationDetail", params)
+            headers = request.headers
+            body = self.call("DescribeDeployApplicationDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDeployApplicationDetailResponse()
@@ -291,7 +329,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeEnvironments", params)
+            headers = request.headers
+            body = self.call("DescribeEnvironments", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeEnvironmentsResponse()
@@ -319,7 +358,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIngress", params)
+            headers = request.headers
+            body = self.call("DescribeIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIngressResponse()
@@ -347,7 +387,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeIngresses", params)
+            headers = request.headers
+            body = self.call("DescribeIngresses", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeIngressesResponse()
@@ -375,7 +416,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRelatedIngresses", params)
+            headers = request.headers
+            body = self.call("DescribeRelatedIngresses", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRelatedIngressesResponse()
@@ -403,7 +445,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GenerateApplicationPackageDownloadUrl", params)
+            headers = request.headers
+            body = self.call("GenerateApplicationPackageDownloadUrl", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GenerateApplicationPackageDownloadUrlResponse()
@@ -431,7 +474,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyApplicationInfo", params)
+            headers = request.headers
+            body = self.call("ModifyApplicationInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyApplicationInfoResponse()
@@ -459,7 +503,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyApplicationReplicas", params)
+            headers = request.headers
+            body = self.call("ModifyApplicationReplicas", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyApplicationReplicasResponse()
@@ -487,7 +532,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyEnvironment", params)
+            headers = request.headers
+            body = self.call("ModifyEnvironment", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyEnvironmentResponse()
@@ -515,7 +561,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyIngress", params)
+            headers = request.headers
+            body = self.call("ModifyIngress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyIngressResponse()
@@ -533,6 +580,35 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RestartApplication(self, request):
+        """服务重启
+
+        :param request: Request instance for RestartApplication.
+        :type request: :class:`tencentcloud.tem.v20210701.models.RestartApplicationRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.RestartApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestartApplication", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RestartApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RestartApplicationPod(self, request):
         """重启应用实例
 
@@ -543,7 +619,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RestartApplicationPod", params)
+            headers = request.headers
+            body = self.call("RestartApplicationPod", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RestartApplicationPodResponse()
@@ -571,7 +648,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResumeDeployApplication", params)
+            headers = request.headers
+            body = self.call("ResumeDeployApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResumeDeployApplicationResponse()
@@ -599,7 +677,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RevertDeployApplication", params)
+            headers = request.headers
+            body = self.call("RevertDeployApplication", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RevertDeployApplicationResponse()
@@ -627,7 +706,8 @@ class TemClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RollingUpdateApplicationByVersion", params)
+            headers = request.headers
+            body = self.call("RollingUpdateApplicationByVersion", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RollingUpdateApplicationByVersionResponse()
@@ -638,6 +718,35 @@ class TemClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopApplication(self, request):
+        """服务停止
+
+        :param request: Request instance for StopApplication.
+        :type request: :class:`tencentcloud.tem.v20210701.models.StopApplicationRequest`
+        :rtype: :class:`tencentcloud.tem.v20210701.models.StopApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopApplication", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
